.. title:: User guide : contents

.. _user_guide:


==========
User guide
==========

.. toctree::
  :numbered:

  modules/eigenpro.rst
  modules/cluster.rst
  modules/robust.rst
  modules/kernel_approximation.rst
